@@ -31,7 +31,7 @@
 ;;; Synched up with: Not synched.
 
 ;; LCD Archive Entry
-;; supercite|Barry A. Warsaw|supercite-help@anthem.nlm.nih.gov
+;; supercite|Barry A. Warsaw|supercite-help@python.org
 ;; |Mail and news reply citation package
 ;; |1993/09/22 18:58:46|3.1|
 
@@ -535,7 +535,7 @@ string."
 
 (defconst sc-version "3.1"
   "Supercite version number.")
-(defconst sc-help-address "supercite-help@anthem.nlm.nih.gov"
+(defconst sc-help-address "supercite-help@python.org"
   "Address accepting submissions of bug reports.")
 
 (defvar sc-mail-info nil
